@@ -90,7 +90,8 @@ def get_es_kwargs_from_config() -> dict[str, Any]:
 
 
 def _ensure_ti(ti: TaskInstanceKey | TaskInstance, session) -> TaskInstance:
-    """Given TI | TIKey, return a TI object.
+    """
+    Given TI | TIKey, return a TI object.
 
     Will raise exception if no TI is found in the database.
     """
@@ -157,14 +158,14 @@ class ElasticsearchTaskHandler(FileTaskHandler, ExternalLoggingMixin, LoggingMix
         index_patterns_callable: str = conf.get("elasticsearch", "index_patterns_callable", fallback=""),
         es_kwargs: dict | None | Literal["default_es_kwargs"] = "default_es_kwargs",
         *,
-        filename_template: str | None = None,
         log_id_template: str | None = None,
+        **kwargs,
     ):
         es_kwargs = es_kwargs or {}
         if es_kwargs == "default_es_kwargs":
             es_kwargs = get_es_kwargs_from_config()
         host = self.format_url(host)
-        super().__init__(base_log_folder, filename_template)
+        super().__init__(base_log_folder)
         self.closed = False
 
         self.client = elasticsearch.Elasticsearch(host, **es_kwargs)
